package com.mobvcasting.activitytoactivity;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.Toast;

// This first activity extends OnClickListener so that it can respond to the button pushes
public class ActivityToActivity extends Activity implements OnClickListener {

	// There are two buttons.  We'll declare them here so we can reference them in any method
	Button button1, button2;
	
	// We define a constant to refer to the other activity so we know when it returns to us
	final static int OTHER_ACTIVITY = 0;
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        
        // As usual, we'll use the interface defined in main.xml
        setContentView(R.layout.main);
        
        // Inside the onCreate method we'll get a reference to each of the buttons defined in the XML
        button1 = (Button) this.findViewById(R.id.Button01);
        button2 = (Button) this.findViewById(R.id.Button02);
        
        // Now tell each of the buttons to tell our activity when they have been pushed.
        // We can do this because our Activity is registered as the OnClickListener
        button1.setOnClickListener(this);
        button2.setOnClickListener(this);
    }

	public void onClick(View v) {
		// If button1 was clicked we'll do this
		if (v == button1) {
			
			// This is the intent to trigger the second activity
			Intent passingIntent = new Intent(this,OtherActivity.class);
			// We can put extra data into this intent
			passingIntent.putExtra("buttonpushed", 1);
			// Now we can use the intent to start the other activity
			startActivityForResult(passingIntent, OTHER_ACTIVITY);
		} else if (v == button2) {
			// If button2 was clicked we'll do this

			// This is the intent to trigger the second activity
			Intent passingIntent = new Intent(this,OtherActivity.class);
			// We can put extra data into this intent
			passingIntent.putExtra("buttonpushed", 2);
			// Now we can use the intent to start the other activity
			startActivityForResult(passingIntent, OTHER_ACTIVITY);
		}
	}

	protected void onActivityResult(int requestCode, int resultCode, Intent intent) {               
        super.onActivityResult(requestCode, resultCode, intent);

        if (requestCode == OTHER_ACTIVITY) {
        	if (resultCode == RESULT_OK) {
        		int otherpushedbutton = intent.getIntExtra("otherpushedbutton", -1);
        		if (otherpushedbutton != -1) {
        			Toast t = Toast.makeText(this, "The " + otherpushedbutton + " was pushed", Toast.LENGTH_SHORT);
        			t.show();        			
        		} else {
        			Toast t = Toast.makeText(this, "No Button was pushed", Toast.LENGTH_SHORT);
        			t.show();
        		}
        	}
        }
	}
}